@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyBrowser.cpp 7166 2007-07-15 10:19:27Z chpe $
+ *  $Id: EphyBrowser.cpp 7626 2007-11-05 19:54:41Z xan $
  */
 
 #include "mozilla-config.h"
@@ -566,13 +566,13 @@ EphyBrowser::~EphyBrowser ()
 	LOG ("EphyBrowser dtor (%p)", this);
 }
 
-nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
+nsresult EphyBrowser::Init (EphyEmbed *embed)
 {
 	if (mInitialized) return NS_OK;
 
-	mEmbed = GTK_WIDGET (mozembed);
+	mEmbed = GTK_WIDGET (embed);
 
-	gtk_moz_embed_get_nsIWebBrowser (mozembed,
+	gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (gtk_bin_get_child (GTK_BIN (embed))),
 					 getter_AddRefs(mWebBrowser));
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
