@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyUtils.cpp 7274 2007-08-15 07:46:04Z diegoe $
+ *  $Id: EphyUtils.cpp 7972 2008-02-20 20:19:50Z xan $
  */
 
 #include "mozilla-config.h"
@@ -39,7 +39,6 @@
 
 #ifdef HAVE_GECKO_1_9
 #include <nsPIDOMWindow.h>
-#include <nsDOMJSUtils.h> /* for GetScriptContextFromJSContext */
 #include <nsIScriptContext.h>
 #include <nsIScriptGlobalObject.h>
 #endif
@@ -132,7 +131,7 @@ EphyUtils::FindEmbed (nsIDOMWindow *aDOMWindow)
 	rv = window->GetSiteWindow ((void **) cache_ptr);
 	NS_ENSURE_SUCCESS (rv, nsnull);
 
-	return mozembed;
+	return gtk_widget_get_parent (mozembed);
 }
 
 GtkWidget *
@@ -172,6 +171,9 @@ EphyUtils::ConvertUTF16toUTF8 (const PRUnichar *aText,
 PRBool
 EphyJSUtils::IsCalledFromScript ()
 {
+#if 1
+	return PR_FALSE;
+#else
 	nsresult rv;
 	nsCOMPtr<nsIXPConnect> xpc(do_GetService(nsIXPConnect::GetCID(), &rv));
 	NS_ENSURE_SUCCESS (rv, PR_FALSE);
@@ -181,16 +183,17 @@ EphyJSUtils::IsCalledFromScript ()
 	NS_ENSURE_SUCCESS(rv, PR_FALSE);
 
 	return nsnull != ncc;
+#endif
 }
 
 /* NOTE: Only call this when we're SURE that we're called directly from JS! */
 nsIDOMWindow *
 EphyJSUtils::GetDOMWindowFromCallContext ()
 {
-  /* TODO: We can do this on 1.8 too, but we'd need to use headers which include private string API
+  /* TODO: We could do this on 1.8, but we'd need to use headers which include private string API
    * so we'll have to move this to MozillaPrivate
    */
-#ifdef HAVE_GECKO_1_9
+#if 0
   nsresult rv;
   nsCOMPtr<nsIXPConnect> xpc (do_GetService(nsIXPConnect::GetCID(), &rv));
   NS_ENSURE_SUCCESS (rv, nsnull);
