@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-toolbar.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-toolbar.h 7364 2007-09-09 22:43:58Z cosimoc $
  */
 
 #ifndef EPHY_TOOLBAR_H
@@ -86,6 +86,10 @@ void		ephy_toolbar_set_navigation_actions	(EphyToolbar *toolbar,
 							 gboolean forward,
 							 gboolean up);
 
+void		ephy_toolbar_set_navigation_tooltips	(EphyToolbar *toolbar,
+							 const char *back_title,
+							 const char *forward_title);
+
 void		ephy_toolbar_set_security_state		(EphyToolbar *toolbar,
 							 gboolean is_secure,
 							 gboolean show_lock,
